<?php

require 'modules/gateway/IridiumCorp/iridium/Config.php';
require 'modules/gateway/iridiumcorp/iridium/iridium.php';

class Gateway {

    private $_config;
    private $_module;
    private $_basket;
    private $_result_message;
    private $_url;
    private $_path;

    public function __construct($module = false, $basket = false) {

        $this -> _db = &$GLOBALS['db'];

        $this -> _module = $module;
        $this -> _basket = &$GLOBALS['cart'] -> basket;

        if ($this -> _module['mode'] != 'hpf' && (!$GLOBALS['db'] -> misc(IridiumSQL::TableExists(IridiumSQL::tblGEP_EntryPoints)))) {
            $GLOBALS['db'] -> misc(IridiumSQL::createGEP_EntryPoints());
        }
    }

    ##################################################

    public function transfer() {

        if ($this -> _module['mode'] == 'hpf') {
            require 'modules/gateway/IridiumCorp/iridium/Config.php';
            $transfer = array('action' => "https://mms.iridiumcorp.net/Pages/PublicPages/PaymentForm.aspx", 'method' => 'post', 'target' => '_self', 'submit' => '');
        } else {
            $transfer = array('action' => "", 'method' => 'post', 'target' => '_self', 'submit' => '');
        }
        return $transfer;
    }

    ##################################################

    public function repeatVariables() {
        return (isset($hidden)) ? $hidden : false;
    }

    public function fixedVariables() {

        $hidden['gateway'] = basename(dirname(__FILE__));

        return (isset($hidden)) ? $hidden : false;
    }

    public function call() {

        $order = Order::getInstance();
        $cart_order_id = $this -> _basket['cart_order_id'];
        $order_summary = $order -> getSummary($cart_order_id);

        switch ($_REQUEST['mode']) {
            case "receive" :
                require_once ("iridium/Hosted/ReceiveTransactionResult.php");
                break;
            case "display" :
                require_once ("iridium/Hosted/DisplayTransactionResult.php");
                break;
            case "3ds" :
                require_once (__DIR__ . "/iridium/Direct/3DSecureCallback.php");
                break;
        }

        if ($_REQUEST['mode'] != "receive" && !$Iridium -> HasActiveError()) {
            require 'iridium/HandleTransactionResults.php';
            return HandleTransactionResults($Iridium, $CallingFunction, $order, $order_summary);
        }
    }

    public function process() {

        require 'iridium/Config.php';

        $order = Order::getInstance();
        $cart_order_id = $this -> _basket['cart_order_id'];
        $order_summary = $order -> getSummary($cart_order_id);

        if ($this -> _module['mode'] == 'hpf') {

            $Iridium = new IridiumHosted("CubeCart");
            $Iridium -> setHostedFormMethod(HostedFormMethod::Process);

        } else {

            $Iridium = new IridiumDirect("CubeCart");
        }

        $Iridium -> setDebugMode($this -> _module['testMode']);
        $Iridium -> setDebugEmailAddress($DeveloperEmailAddress);
        //$Iridium->setDatabaseSupport(TRUE);

        $Iridium -> setPaymentProcessorFullDomain($PaymentProcessorFullDomain);
        $Iridium -> setTransactionType(TransactionType::Sale);
        //$Iridium->setOriginCrossReference($params['gatewayid']);

        if (!$this -> _module['testMode']) {
            $Iridium -> setMerchantID($this -> _module['mid_test']);
            $Iridium -> setPassword($this -> _module['pass_test']);
        } else {
            $Iridium -> setMerchantID($this -> _module['mid_prod']);
            $Iridium -> setPassword($this -> _module['pass_prod']);
        }

        $Iridium -> setOrderID($this -> _basket['cart_order_id']);
        $Iridium -> setOrderDescription("Order ID: " . $Iridium -> getOrderID());

        $Iridium -> setAddress1($this -> _basket['billing_address']['line1']);
        $Iridium -> setAddress2($this -> _basket['billing_address']['line2']);
        $Iridium -> setCity($this -> _basket['billing_address']['town']);
        $Iridium -> setState($this -> _basket['billing_address']['state']);
        $Iridium -> setPostCode($this -> _basket['billing_address']['postcode']);
        $Iridium -> setCountry($this -> _basket['billing_address']['country_id']);
        $Iridium -> setEmailAddress($this -> _basket['billing_address']['email']);
        $Iridium -> setPhoneNumber($this -> _basket['billing_address']['phone']);

        $nAmountWithDecimals = $this -> _basket['total'];
        if ($nAmountWithDecimals == "0.00" || $nAmountWithDecimals == NULL || $CallingFunction == "iridium_storeremote") {
            $nAmountWithDecimals = 0.01;
        }
        $Iridium -> setTransactionAmountAndCurrency($nAmountWithDecimals, $GLOBALS['config'] -> get('config', 'default_currency'));

        if ($this -> _module['mode'] != 'hpf') {

            $SuccessfulGatewayEntryPoint = null;

            $SuccessfulGatewayEntryPoint = $GLOBALS['db'] -> misc(IridiumSQL::selectGEP_EntryPoint(10));
            $SuccessfulGatewayEntryPoint = $SuccessfulGatewayEntryPoint[0]['GatewayEntryPoint'];

            $Iridium -> setGatewayEntryPointToAttemptFirst($SuccessfulGatewayEntryPoint);

            $Iridium -> setTransactionMethod(TransactionMethod::CardDetailsTransaction);

            $Iridium -> setCardName("{$_POST['firstName']} {$_POST['lastName']}");
            $Iridium -> setCardNumber($_POST['cardNumber']);

            //$CardExpiry = GetExpiryDate($params['cardexp'], $MerchantDetails['CA']);
            $Iridium -> setCardExpiryDateMonth($_POST['expirationMonth']);
            $Iridium -> setCardExpiryDateYear(substr($_POST['expirationYear'], -2));

            $CardStart = $params['cardstart'];
            if ($CardStart) {
                $Iridium -> setCardStartDateMonth(substr($CardStart, 0, 2));
                $Iridium -> setCardStartDateYear(substr($CardStart, -2));
            }

            $Iridium -> setCardIssueNumber($_POST['cardIssueNum']);
            $Iridium -> setCardCV2($_POST['cv2']);
        } else {

            $Iridium -> setCardName("{$this->_basket['billing_address']['first_name']} {$this->_basket['billing_address']['last_name']}");

            $Iridium -> setHostedFormMethod(HostedFormMethod::Process);
            $Iridium -> setTransactionType(TransactionType::Sale);
            $Iridium -> setThreeDSecureOverridePolicy(TRUE);

            $Iridium -> setHostedFormReturnType(HostedFormReturnType::HTMLFormCode);

            $Iridium -> setHTML_IncludeFormTags(FALSE);
            $Iridium -> setHTML_IncludeSubmitButton(FALSE);

            $Iridium -> setHashMethod($this -> _module['hpfHashMethod']);
            $Iridium -> setPreSharedKey($this -> _module['hpfPreSharedKey']);
            $Iridium -> setResultDeliveryMethod($this -> _module['hpfResultDeliveryMethod']);

            $Iridium -> setTransactionDateTime(date('Y-m-d H:i:s P'));

            $Iridium -> setEmailAddressEditable(true);
            $Iridium -> setPhoneNumberEditable(true);

            $Iridium -> setCV2Mandatory($this -> _module['hpfCV2Mandatory']);
            $Iridium -> setAddress1Mandatory($this -> _module['hpfAddress1Mandatory']);
            $Iridium -> setCityMandatory($this -> _module['hpfCityMandatory']);
            $Iridium -> setPostCodeMandatory($this -> _module['hpfPostCodeMandatory']);
            $Iridium -> setStateMandatory($this -> _module['hpfStateMandatory']);
            $Iridium -> setCountryMandatory($this -> _module['hpfCountryMandatory']);

            if ($this -> _module['hpfResultDeliveryMethod'] != ResultDeliveryMethod::SERVER) {
                $Iridium -> setServerResultURL(NULL);
            } else {
                $Iridium -> setServerResultURL('index.php?_g=rm&type=gateway&cmd=call&module=IridiumCorp&mode=receive');
                //$Iridium->setServerResultURL('modules/gateway/IridiumCorp/iridium/Hosted/ReceiveTransactionResult.php');
            }

            if ($this -> _module['hpfResultDeliveryMethod'] != ResultDeliveryMethod::SERVER) {
                $Iridium -> setPaymentFormDisplayResult(NULL);
            } else {
                $Iridium -> setPaymentFormDisplayResult(false);
            }

            // the callback URL on this site that will display the transaction
            // result to the customer
            // (always required unless ResultDeliveryMethod = "SERVER" and
            // PaymentFormDisplaysResult = "true")
            if ($this -> _module['hpfResultDeliveryMethod'] == ResultDeliveryMethod::SERVER && $Iridium -> getPaymentFormDisplayResult() == true) {
                $Iridium -> setCallbackURL(NULL);
            } else {
                //$Iridium->setCallbackURL(NULL);
                $Iridium -> setCallbackURL('index.php?_g=rm&type=gateway&cmd=call&module=IridiumCorp&mode=display');
                //$Iridium->setCallbackURL("modules/gateway/IridiumCorp/iridium/Hosted/DisplayTransactionResult.php");
                //$Iridium->setCallbackURL('index.php?_g=rm&type=gateway&cmd=call&module=IridiumCorp');
            }
        }
        $return = $Iridium -> Process();

        if ($this -> _module['mode'] != 'hpf') {
            require __DIR__ . '/iridium/HandleTransactionResults.php';
            $return = HandleTransactionResults($Iridium, __FUNCTION__, $order, $order_summary);
        } else {
            $return = '
                <!DOCTYPE html>
                <html>
                    <head>
                        <title>Launch Payer Authentication Page</title>
                        <script language="javascript">
                        function onLoadHandler(){
                                document.contactForm.submit();
                        }
                        </script>
                    </head>
                    <body onload="onLoadHandler();">' . $return . '
                    </body>
                </html>';
        }

        return $return;
    }

    ##################################################

    private function formatMonth($val) {
        return $val . " - " . strftime("%b", mktime(0, 0, 0, $val, 1, 2009));
    }

    public function form() {

        if ($this -> _module['mode'] == 'hpf') {
            $return = $this -> process();
        } elseif (isset($_POST['cardNumber'])) {

            $return = $this -> process();

            if ($GLOBALS['session'] -> get('DISPLAY_3DS')) {
                return $return;
            }
        } else {

            // Display payment result message
            if (!empty($this -> _result_message)) {
                $GLOBALS['gui'] -> setError($this -> _result_message);
            }

            //Show Expire Months
            $selectedMonth = (isset($_POST['expirationMonth'])) ? $_POST['expirationMonth'] : date('m');
            for ($i = 1; $i <= 12; ++$i) {
                $val = sprintf('%02d', $i);
                $smarty_data['card']['months'][] = array('selected' => ($val == $selectedMonth) ? 'selected="selected"' : '', 'value' => $val, 'display' => $this -> formatMonth($val), );
            }

            ## Show Expire Years
            $thisYear = date("Y");
            $maxYear = $thisYear + 10;
            $selectedYear = isset($_POST['expirationYear']) ? $_POST['expirationYear'] : ($thisYear + 2);
            for ($i = $thisYear; $i <= $maxYear; ++$i) {
                $smarty_data['card']['years'][] = array('selected' => ($i == $selectedYear) ? 'selected="selected"' : '', 'value' => $i, );
            }
            $GLOBALS['smarty'] -> assign('CARD', $smarty_data['card']);

            $smarty_data['customer'] = array('first_name' => isset($_POST['firstName']) ? $_POST['firstName'] : $this -> _basket['billing_address']['first_name'], 'last_name' => isset($_POST['lastName']) ? $_POST['lastName'] : $this -> _basket['billing_address']['last_name'], 'email' => isset($_POST['emailAddress']) ? $_POST['emailAddress'] : $this -> _basket['billing_address']['email'], 'add1' => isset($_POST['addr1']) ? $_POST['addr1'] : $this -> _basket['billing_address']['line1'], 'add2' => isset($_POST['addr2']) ? $_POST['addr2'] : $this -> _basket['billing_address']['line2'], 'city' => isset($_POST['city']) ? $_POST['city'] : $this -> _basket['billing_address']['town'], 'state' => isset($_POST['state']) ? $_POST['state'] : $this -> _basket['billing_address']['state'], 'postcode' => isset($_POST['postcode']) ? $_POST['postcode'] : $this -> _basket['billing_address']['postcode']);

            $GLOBALS['smarty'] -> assign('CUSTOMER', $smarty_data['customer']);

            ## Country list
            $countries = $GLOBALS['db'] -> select('CubeCart_geo_country', false, false, array('name' => 'ASC'));
            if ($countries) {
                $currentIso = isset($_POST['country']) ? $_POST['country'] : $this -> _basket['billing_address']['country_iso'];
                foreach ($countries as $country) {
                    $country['selected'] = ($country['iso'] == $currentIso) ? 'selected="selected"' : '';
                    $smarty_data['countries'][] = $country;
                }
                $GLOBALS['smarty'] -> assign('COUNTRIES', $smarty_data['countries']);
            }

            ## Check for custom template for module in skin folder
            $file_name = 'form.tpl';
            $form_file = $GLOBALS['gui'] -> getCustomModuleSkin('gateway', dirname(__FILE__), $file_name);
            $GLOBALS['gui'] -> changeTemplateDir($form_file);
            $return = $GLOBALS['smarty'] -> fetch($file_name);
            $GLOBALS['gui'] -> changeTemplateDir();
        }
        return $return;
    }

}
